@@ -332,8 +332,7 @@ KDE_NO_EXPORT bool MediaInfo::downloading () const {
 }
 
 KDE_NO_EXPORT void MediaInfo::create () {
-    ActorAgent *mgr = (ActorAgent *)node->document()->message(
-            MsgQueryActorAgent);
+    ActorAgent *mgr = (ActorAgent *)node->document()->role(RoleActorAgent);
     if (!media) {
         switch (type) {
             case ActorAgent::Audio:
@@ -452,7 +451,7 @@ bool AudioVideoActor::play () {
     Process *process = m_agent->control ()->process ();
     if (process && process->playing () && process->mrl () == mrl ()) {
         errorLog () << "play: already playing " << mrl ()->src << endl;
-    } else if (m_agent->control ()->requestPlayURL (m_node)) {
+    } else if (m_agent->control ()->requestPlayURL (mrl ())) {
         if (!mrl ()->audio_only)
             m_agent->control ()->viewArea ()->setAudioVideoNode (m_node);
         ignore_pause = true;
@@ -550,7 +549,7 @@ ImageActor::ImageActor (ActorAgent *manager, Node *node,
 }
 
 ImageActor::ImageActor (Node *node, ImageDataPtr id)
- : Actor ((ActorAgent *)node->document()->message(MsgQueryActorAgent),
+ : Actor ((ActorAgent *)node->document()->role(RoleActorAgent),
          node),
    img_movie (NULL),
    img_movie_iter (NULL),
