@@ -158,7 +158,7 @@ struct KMPLAYER_NO_EXPORT ImageData {
     ~ImageData();
     void setImage (Image *img);
     void setImage (cairo_surface_t *s, int w, int h);
-    void copyImage (Surface *s, int w, int h, cairo_surface_t *similar,
+    void copyImage (Surface *s, const SSize &sz, cairo_surface_t *similar,
             unsigned int *penalty, CalculatedSizer *zoom=NULL);
     bool isEmpty () const {
          return !image && !surface; }
@@ -191,7 +191,7 @@ public:
 
     bool isEmpty () const;
     unsigned render (cairo_surface_t *similar, ISize size);
-    void sizes (Single &width, Single &height);
+    void sizes (SSize &size);
     void updateRender ();
     bool movieTimer ();
 
