@@ -92,12 +92,11 @@ KDE_NO_EXPORT KMPlayer::Node *Recents::childFromTag (const String & tag) {
     return FileDocument::childFromTag (tag);
 }
 
-KDE_NO_EXPORT void *Recents::message (KMPlayer::MessageType msg, void *data) {
-    if (KMPlayer::MsgChildFinished) {
+KDE_NO_EXPORT void Recents::message (KMPlayer::MessageType msg, void *data) {
+    if (KMPlayer::MsgChildFinished)
         finish ();
-        return NULL;
-    }
-    return FileDocument::message (msg, data);
+    else
+        FileDocument::message (msg, data);
 }
 
 KDE_NO_CDTOR_EXPORT
@@ -185,12 +184,11 @@ KDE_NO_EXPORT KMPlayer::Node *Playlist::childFromTag (const String & tag) {
     return FileDocument::childFromTag (tag);
 }
 
-KDE_NO_EXPORT void *Playlist::message (KMPlayer::MessageType msg, void *data) {
-    if (KMPlayer::MsgChildFinished && !playmode) {
+KDE_NO_EXPORT void Playlist::message (KMPlayer::MessageType msg, void *data) {
+    if (KMPlayer::MsgChildFinished && !playmode)
         finish ();
-        return NULL;
-    }
-    return FileDocument::message (msg, data);
+    else
+        FileDocument::message (msg, data);
 }
 
 KDE_NO_CDTOR_EXPORT
@@ -544,7 +542,7 @@ void Generator::deactivate () {
     FileDocument::deactivate ();
 }
 
-void *Generator::message (KMPlayer::MessageType msg, void *content) {
+void Generator::message (KMPlayer::MessageType msg, void *content) {
     if (MsgMediaReady == msg) {
         if (!media_info->rawData ().size ()) {
             String err ("No input data received");
@@ -554,9 +552,8 @@ void *Generator::message (KMPlayer::MessageType msg, void *content) {
             begin ();
         }
     } else {
-        return FileDocument::message (msg, content);
+        FileDocument::message (msg, content);
     }
-    return NULL;
 }
 
 void Generator::readEvent (UnixProcess *) {
