@@ -53,6 +53,12 @@ static const short id_node_gen_http_get = 48;
 static const short id_node_gen_http_key_value = 49;
 static const short id_node_gen_sequence = 50;
 
+inline bool isListItem (short id) {
+    return id_node_recent_node == id ||
+        id_node_playlist_item == id ||
+        id_node_html_object == id;
+}
+
 class KMPLAYER_NO_EXPORT FileDocument : public KMPlayer::SourceDocument {
 public:
     FileDocument (short id, const String &, KMPlayer::Control * notify = 0L);
@@ -78,7 +84,7 @@ public:
     Recents (Application *a);
     void defer ();
     void activate ();
-    void *message (KMPlayer::MessageType msg, void *content=NULL);
+    void message (KMPlayer::MessageType msg, void *content=NULL);
     KMPlayer::Node *childFromTag (const String & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "playlist"; }
     String path;
@@ -106,7 +112,7 @@ public:
 class KMPLAYER_NO_EXPORT Playlist : public FileDocument {
 public:
     Playlist (Application *a, KMPlayer::Control *n, bool plmod = false);
-    void *message (KMPlayer::MessageType msg, void *content=NULL);
+    void message (KMPlayer::MessageType msg, void *content=NULL);
     void defer ();
     void activate ();
     KMPlayer::Node *childFromTag (const String & tag);
@@ -162,7 +168,7 @@ public:
     void activate ();
     void begin ();
     void deactivate ();
-    void *message (KMPlayer::MessageType msg, void *content=NULL);
+    void message (KMPlayer::MessageType msg, void *content=NULL);
     Node *childFromTag (const String & tag);
     KDE_NO_EXPORT const char *nodeName () const { return "generator"; }
 
