@@ -40,7 +40,7 @@ typedef std::vector <String> StringList;
 class KMPLAYER_NO_EXPORT SizeType {
 public:
     SizeType ();
-    SizeType (const String & s);
+    SizeType (const String & s, bool force_perc=false);
     void reset ();
     SizeType & operator = (const String & s);
     SizeType & operator += (const SizeType & s);
@@ -307,6 +307,7 @@ public:
 
     int z_order;
     unsigned int background_color;
+    int bg_opacity;
     String background_image;
     ShowBackground show_background;
     Fit fit;
@@ -624,7 +625,9 @@ public:
     CalculatedSizer sizes;
     CalculatedSizer *pan_zoom;
     Fit fit;
+    unsigned int background_color;
     int opacity;
+    int bg_opacity;
     unsigned int bitrate;
     unsigned int trans_start_time;
     unsigned int trans_end_time;
@@ -684,8 +687,6 @@ public:
     String font_name;
     int font_size;
     unsigned int font_color;
-    unsigned int background_color;
-    int bg_opacity;
     enum { align_left, align_center, align_right } halign;
 };
 
