@@ -138,7 +138,7 @@ int populate (GtkTreeStore * tree_store, PlayListData * pld,
     //if (e->active ())
     //    ; //ensureItemVisible (item);
     if (e->isElementNode ()) {
-        Attribute *a = convertNode<Element> (e)->attributes ()->first ();
+        Attribute *a = static_cast <Element *> (e)->attributes ()->first ();
         if (a) {
             m_have_dark_nodes = true;
             if (pld->show_all) {
@@ -191,7 +191,7 @@ static gboolean findNode (PlayListData *pld, GtkTreeModel *model, Node *node, Gt
                     if (!gtk_tree_model_iter_children (model, iter, &piter))
                         return false;
                     if (pld->show_all && n->isElementNode () &&
-                            convertNode<Element>(n)->attributes()->first() &&
+                            static_cast<Element*>(n)->attributes()->first() &&
                             !gtk_tree_model_iter_next (model, iter))
                         return false;
                 } else if (!gtk_tree_model_iter_next (model, iter)) {
@@ -396,7 +396,7 @@ static Node *getNode (PlayListData * pld, GtkTreePath * path) {
     if (pld->show_all) {
         for (int i = 1; node && i < depth; i++) {
             bool has_attrs = (node->isElementNode () &&
-                    convertNode<Element> (node)->attributes ()->first ());
+                    static_cast<Element *> (node)->attributes ()->first ());
             int index = idxs [i] - (has_attrs ? 1 : 0);
             //    g_print ("cb_selection_changed %d->%d\n", idxs [i], index);
             node = index < 0 ? 0L : node->childNodes ()->item (index);
@@ -734,10 +734,7 @@ void cb_playlistMenuActivate (GtkButton * button, Application * app) {
     if (pld) {
         Node *node = getNode (pld, path);
         if (node) {
-            show_copy = node->id == id_node_recent_node ||
-                //node->id == id_node_group_node ||
-                node->id == id_node_playlist_item ||
-                node->id == id_node_html_object ||
+            show_copy = isListItem (node->id) ||
                 (pld->id == 0 &&
                  node->mrl () &&
                  node->id != id_node_playlist_document &&
@@ -767,9 +764,7 @@ void cb_playlistCopy (GtkButton * button, Application * app) {
         Node *node = getNode (pld, path);
         if (node && node->mrl ()) {
             CONTROL(app)->copyPasteNode = 0L;
-            if (node->id == id_node_recent_node ||
-                    node->id == id_node_playlist_item ||
-                    node->id == id_node_html_object) {
+            if (isListItem (node->id)) {
                 CONTROL(app)->copyPasteXml = node->outerXML (false);
             } else {
                 TextStream txt;
