@@ -80,6 +80,51 @@ KMPLAYER_NO_EXPORT ByteArrayImpl &ByteArrayImpl::operator = (const char *b) {
 
 //-----------------------------------------------------------------------------
 
+void *FixedSizeAllocator::alloc () {
+    return count ? pool[--count] : malloc (size);
+}
+
+void FixedSizeAllocator::dealloc (void *p) {
+    if (count < 10)
+        pool[count++] = p;
+    else
+        free (p);
+}
+
+//-----------------------------------------------------------------------------
+
+static FixedSizeAllocator *shared_data_pool;
+
+namespace KMPlayer {
+
+void *sharedDataAlloc (size_t s) {
+    if (!shared_data_pool)
+        shared_data_pool = new FixedSizeAllocator (s);
+
+    return shared_data_pool->alloc ();
+}
+
+void sharedDataFree (void *p) {
+    shared_data_pool->dealloc (p);
+}
+
+}
+
+//-----------------------------------------------------------------------------
+
+static FixedSizeAllocator *shared_chars_pool;
+
+void *SharedChars::operator new (size_t s) {
+    if (!shared_chars_pool)
+        shared_chars_pool = new FixedSizeAllocator (sizeof (SharedChars));
+
+    return shared_chars_pool->alloc ();
+}
+
+void SharedChars::operator delete (void *p) {
+    shared_chars_pool->dealloc (p);
+}
+
 template <>
 void Shared<SharedChars>::attach (const Shared<SharedChars> &other) {
     if (data != other.data) {
@@ -163,41 +208,49 @@ static char *strCat (const gchar *p1, int len1, const gchar *p2, int len2) {
     return p;
 }
 
+void GLibString::append (const char *p, int length) {
+    if (!data) {
+        takeUtf8 (g_strndup (p, length), length);
+    } else {
+        if (data->buf_len < 0)
+            data->buf_len = strlen (data->ptr);
+        if (1 == data->ref_count) {
+            data->ptr = (gchar *) g_realloc (data->ptr,
+                    data->buf_len + length + 1);
+            memcpy (data->ptr + data->buf_len, p, length);
+            data->buf_len += length;
+            data->ptr [data->buf_len] = 0;
+        } else {
+            takeUtf8 (strCat (data->ptr, data->buf_len, p, length),
+                    data->buf_len + length);
+        }
+    }
+}
+
 GLibString & GLibString::operator += (const GLibString &str) {
     if (str.data) {
         if (!data) {
             attach (str);
         } else {
-            if (data->buf_len < 0)
-                data->buf_len = strlen (data->ptr);
             int slen = str.data->buf_len;
             if (slen < 0)
                 slen = strlen (str.data->ptr);
-            if (1 == data->ref_count) {
-                data->ptr = (gchar *) g_realloc (data->ptr,
-                                                 data->buf_len + slen + 1);
-                memcpy (data->ptr + data->buf_len, str.data->ptr, slen);
-                data->buf_len += slen;
-                data->ptr [data->buf_len] = 0;
-            } else {
-                takeUtf8(strCat (data->ptr, data->buf_len, str.data->ptr, slen),
-                         data->buf_len + slen);
-            }
+            append (str.data->ptr, slen);
         }
     }
     return *this;
 }
 
-KMPLAYER_NO_EXPORT GLibString & GLibString::operator += (const char *str) {
-    int slen = strlen (str);
-    if (!data) {
-        takeUtf8 (g_strdup (str), slen);
-    } else {
-        if (data->buf_len < 0)
-            data->buf_len = strlen (data->ptr);
-        takeUtf8 (strCat (data->ptr, data->buf_len, str, slen),
-                  data->buf_len + slen);
-    }
+KMPLAYER_NO_EXPORT GLibString &GLibString::operator += (const char *str) {
+    append (str, strlen (str));
+    return *this;
+}
+
+KMPLAYER_NO_EXPORT GLibString &GLibString::operator += (const Char &ch) {
+    gchar buf [8];
+    int nr = g_unichar_to_utf8 (ch.unicode (), buf);
+    buf [nr] = 0;
+    append (buf, nr);
     return *this;
 }
 
@@ -210,35 +263,34 @@ GLibString GLibString::fill (Char ch, int length) {
 GLibString GLibString::stripWhiteSpace () const {
     String str;
     if (data && data->ptr [0]) {
-        String ws;
-        gchar * iter = data->ptr;
+        gchar *iter = data->ptr;
+        gchar *first = iter;
+        gchar *end = iter;
         Char ch (g_utf8_get_char (iter));
         iter = g_utf8_next_char (iter);
         while (ch.isSpace () && iter && *iter) { // skip leading ws
             ch = Char (g_utf8_get_char (iter));
+            first = iter;
             iter = g_utf8_next_char (iter);
         }
         if (ch.isSpace ())
             return str;
-        str += ch;
+        end = first + 1;
         do {
             if (!iter || !*iter)
                 break;
             ch = Char (g_utf8_get_char (iter));
             iter = g_utf8_next_char (iter);
             while (ch.isSpace () && iter && *iter) {
-                ws += ch;
                 ch = Char (g_utf8_get_char (iter));
                 iter = g_utf8_next_char (iter);
             }
             if (ch.isSpace ())
                 break;  // skip ending ws
-            if (!ws.isEmpty ()) {
-                str += ws;
-                ws.truncate (0);
-            }
-            str += ch;
+            end = iter;
         } while (iter && *iter);
+        if (end > first)
+            str.append (first, end - first);
     }
     return str;
 }
@@ -294,13 +346,13 @@ GLibString GLibString::replace (Char c1, Char c2) const {
         gchar *p = strstr (s, cstr1);
         while (p) {
             if (p != s)
-                str += GLibString (s, p - s);
-            str += GLibString (cstr2);
+                str.append (s, p - s);
+            str.append (cstr2, nr2);
             s = p + nr1;
             p = strstr (s, cstr1);
         }
         if (s[0])
-            str += GLibString (s);
+            str.append (s, strlen (s));
     }
     return str;
 }
@@ -1186,6 +1238,16 @@ KMPLAYER_NO_CDTOR_EXPORT GConf::~GConf () {
     g_object_unref (client);
 }
 
+KMPLAYER_NO_EXPORT
+String GConf::readEntry (const String & key, const String & def) {
+    gchar *val = gconf_client_get_string (client, (const char *) key, 0L);
+    if (!val)
+        return def;
+    String s;
+    s.take (val);
+    return s;
+}
+
 KMPLAYER_NO_EXPORT int GConf::readNumEntry (const String & key, int def) {
     GConfValue *val = gconf_client_get (client, (const char *) key, 0L);
     if (val) {
