@@ -226,6 +226,19 @@ public:
 
 typedef ByteArrayImpl ByteArray;
 
+
+class FixedSizeAllocator {
+    void **pool;
+    size_t size;
+    int count;
+public:
+    FixedSizeAllocator (size_t s)
+        : pool ((void**) malloc (10 * sizeof (void *))), size (s), count (0) {}
+
+    void *alloc ();
+    void dealloc (void *p);
+};
+
 template <class T>
 class Shared {
 public:
@@ -246,6 +259,8 @@ struct SharedChars {
     SharedChars (const SharedChars &s)
         : ptr(g_strdup (s.ptr)), ref_count (1), buf_len (s.buf_len) {}
     ~SharedChars () { g_free (ptr); }
+    void *operator new (size_t);
+    void operator delete (void *);
     void ref () { ref_count++; }
     void unref () { if (--ref_count <= 0) delete this; }
     int ref_count;
@@ -263,6 +278,7 @@ public:
     GLibString (const char * str, int maxlen = -1);
     GLibString (const Char & str);
     ~GLibString ();
+    void append (const char *p, int length);  // p must be valid utf8
     void takeUtf8 (char *p, int buf_len=-1);  // p must be valid utf8
     int compare (const char *str) const;
     int compare (const GLibString & str) const;
@@ -985,11 +1001,6 @@ inline GLibString & GLibString::operator = (const GLibString &str) {
     return *this;
 }
 
-KMPLAYER_NO_EXPORT
-inline GLibString & GLibString::operator += (const Char & ch) {
-    return *this += GLibString (ch);
-}
-
 KMPLAYER_NO_EXPORT inline GLibString::operator const char * () const {
     return data ? data->ptr : "";
 }
@@ -1166,12 +1177,6 @@ inline String GMimeType::findByURL (const URL & url) {
 
 //-----------------------------------------------------------------------------
 
-KMPLAYER_NO_EXPORT
-inline String GConf::readEntry (const String & key, const String & def) {
-    gchar * val = gconf_client_get_string (client, (const char *) key, 0L);
-    return val ? String (val) : def;
-}
-
 KMPLAYER_NO_EXPORT
 inline void GConf::writeEntry (const String & key, const String & val) {
     gconf_client_set_string (client, (const char *) key, (const char *)val, 0L);
